import 'package:flutter/material.dart';
import 'package:getsocial_flutter_sdk/getsocial_flutter_sdk.dart';
import 'activities.dart';
import 'main.dart';

class TagSearch extends StatefulWidget {
  @override
  TagSearchState createState() => new TagSearchState();
}

class TagSearchState extends State<TagSearch> {
  List<String> tags = [];
  late String searchText;
  static bool showOnlyTrending = false;

  @override
  void initState() {
    searchText = '';
    executeSearch();
    super.initState();
  }

  executeSearch() async {
    TagsQuery query = TagsQuery.find(searchText);
    query = query.onlyTrending(showOnlyTrending);
    Communities.getTags(query).then((entries) {
      this.setState(() {
        tags = entries;
      });
    });
  }

  showFeedWithTags(String tag) async {
    Navigator.pop(context);
    ActivitiesState.query = ActivitiesQuery.everywhere()
        .withTag(tag)
        .withPollStatus(PollStatus.withoutPoll);
    ActivitiesState.canInteract = true;
    ActivitiesState.isComment = false;
    Navigator.pushNamed(context, '/activities');
  }

  @override
  Widget build(BuildContext context) {
    buildContextList.add(context);
    return Column(
      children: [
        Container(
            child: new TextButton(
              onPressed: () {
                buildContextList.removeLast();
                Navigator.pop(context);
              },
              child: new Text('< Back'),
              style: TextButton.styleFrom(
                  backgroundColor: Colors.blue, primary: Colors.white),
            ),
            decoration: new BoxDecoration(
                color: Colors.white,
                border: new Border(bottom: new BorderSide()))),
        Container(
            child: new TextButton(
              onPressed: () {
                buildContextList.removeLast();
                showOnlyTrending = !showOnlyTrending;
                executeSearch();
              },
              child: new Text(showOnlyTrending ? 'All' : 'Only Trending'),
              style: TextButton.styleFrom(
                  backgroundColor: Colors.blue, primary: Colors.white),
            ),
            decoration: new BoxDecoration(
                color: Colors.white,
                border: new Border(bottom: new BorderSide()))),
        Row(
          children: [
            Expanded(
              child: TextFormField(
                  onChanged: (value) => setState(() {
                        searchText = value;
                      })),
            ),
            ElevatedButton(
              onPressed: () {
                executeSearch();
              },
              child: Text('Search'),
            )
          ],
        ),
        Expanded(
            child: ListView.builder(
                padding: const EdgeInsets.all(0),
                itemCount: tags.length,
                itemBuilder: (BuildContext context, int index) {
                  var tag = tags[index];
                  return Container(
                      child: Row(
                        children: [
                          Expanded(
                            child: Text(tag),
                          ),
                          TextButton(
                            onPressed: () => showFeedWithTags(tag),
                            child: Text('Show all posts'),
                            style: TextButton.styleFrom(
                                backgroundColor: Colors.blue,
                                primary: Colors.white),
                          ),
                        ],
                      ),
                      decoration: new BoxDecoration(
                          color: Colors.white,
                          border: new Border(bottom: new BorderSide())));
                })),
      ],
    );
  }
}
