import '../common/codable.dart';
import '../common/userid.dart';
import '../src/communitiesids.dart';

/// Describe PostActivityTarget object.
class PostActivityTarget extends Encodable {
  late CommunitiesIds ids;

  PostActivityTarget(CommunitiesIds ids) {
    this.ids = ids;
  }

  /// Create PostActivityTarget with a topic.
  /// [id]  Topic id.
  static PostActivityTarget topic(String id) {
    return PostActivityTarget(CommunitiesIds.topic(id));
  }

  /// Create PostActivityTarget with a group.
  /// [id]  Group id.
  static PostActivityTarget group(String id) {
    return PostActivityTarget(CommunitiesIds.group(id));
  }

  /// Create PostActivityTarget for timeline.
  static PostActivityTarget timeline() {
    return PostActivityTarget(CommunitiesIds.user(UserId.currentUser()));
  }

  /// Create PostActivityTarget with an activity.
  /// [activityId]  Activity id.
  static PostActivityTarget comment(String activityId) {
    return PostActivityTarget(CommunitiesIds.activity(activityId));
  }

  Map<String, dynamic> toJSON() => {
        'ids': ids.toJSON(),
      };
}
