import '../common/codable.dart';
import 'dart:io' show Platform;

/// Notification button object
class NotificationButton extends Encodable {
  /// Consume action id.
  static const String consume = 'consume';

  /// Ignore action id.
  static const String ignore = 'ignore';

  NotificationButton.fromJSON(Map<String, dynamic> json)
      : actionId = json['actionId'] == null ? json['id'] : json['actionId'],
        title = json['title'];

  /// Action Id.
  late String actionId;

  /// Button title.
  late String title;

  NotificationButton(String title, String actionId) {
    this.actionId = actionId;
    this.title = title;
  }

  Map<String, dynamic> toJSON() {
    String idKey = Platform.isAndroid ? 'id' : 'actionId';
    return {idKey: actionId, 'title': title};
  }

  @override
  String toString() {
    return 'NotificationButton{'
        'actionId: $actionId, '
        'title: $title'
        '}';
  }
}
