import '../common/codable.dart';

class IdentityProviderIds {
  static const String facebook = 'facebook';
}

class Identity extends Encodable {
  String _provider;
  String? _userId;
  String _token;
  bool _trusted = false;

  Identity._(String provider, String? userId, String token,
      {bool trusted = false})
      : _provider = provider,
        _userId = userId,
        _token = token,
        _trusted = trusted;

  ///
  /// Create custom identity.
  ///
  /// [provider] Your custom provider name.
  /// [userId]             Unique user identifier for your custom provider.
  /// [token]        Password of the user for your custom provider.
  ///                           It's a string, provided by the developer and it will be
  ///                           required by the GetSocial SDK to validate any future
  ///                           intent to add this same identity to another user.
  ///
  Identity.custom(String provider, String userId, String token)
      : this._(provider, userId, token);

  ///
  /// Creates a Facebook identity with specified access token.
  ///
  /// [token] Token of Facebook user returned from FB SDK.
  ///
  Identity.facebook(String token)
      : this._(IdentityProviderIds.facebook, null, token);

  ///
  /// Create trusted identity.
  ///
  /// [provider] Your trusted provider name.
  /// [token]        Password of the user for your trusted provider.
  ///
  Identity.trusted(String provider, String token)
      : this._(provider, null, token, trusted: true);

  Map<String, dynamic> toJSON() => {
        'accessToken': _token,
        'provider': _provider,
        'trusted': _trusted,
        'userId': _userId,
      };
}
