import 'dart:convert';

import 'package:flutter_test/flutter_test.dart';
import 'package:getsocial_flutter_sdk/getsocial_flutter_sdk.dart';

import '../test_utils.dart';

void main() {
  test('Decode', () {
    var obj = jsonDecode(TestUtils.readObjectToDecode('activity.json'));
    var result = GetSocialActivity.fromJSON(obj);
    expect(result.id, 'activityid');
    expect(result.commentsCount, 20);
    expect(result.createdAt, 100);
    expect(result.isAnnouncement, true);
    expect(result.text, 'activitytext');
    expect(result.status, 'status');
    expect(result.properties['activitykey'], 'activityvalue');

    var mentions = result.mentions;
    var mention1 = mentions[0];
    expect(mention1.type, MentionType.user);
    expect(mention1.startIndex, 111);
    expect(mention1.endIndex, 222);
    expect(mention1.userId, 'userId');

    var mention2 = mentions[1];
    expect(mention2.type, MentionType.app);
    expect(mention2.startIndex, 111);
    expect(mention2.endIndex, 222);
    expect(mention2.userId, 'userId');

    var myreactions = result.myReactions;
    expect(myreactions.length, 2);
    expect(myreactions[0], 'like');
    expect(myreactions[1], 'wow');

    var button = result.button;
    expect(button?.title, 'title');

    var action = button?.action;
    expect(action?.type, 'hello2');
    expect(action?.data['actionKey2'], 'actionValue2');

    var reactionsCount = result.reactionsCount;
    expect(reactionsCount['like'], 10);
    expect(reactionsCount['wow'], 5);

    var reactions = result.reactions;
    var reaction1 = reactions[0];
    expect(reaction1.reactions[0], 'hello');

    var reaction1User = reaction1.user;
    expect(reaction1User.userId, 'userid');
    expect(reaction1User.avatarUrl, 'avatarurl');
    expect(reaction1User.displayName, 'testuser');
    expect(reaction1User.identities['fb'], 'token');
    expect(reaction1User.publicProperties['publickey'], 'publicvalue');
    expect(reaction1User.verified, true);

    var reaction2 = reactions[1];
    expect(reaction2.reactions[0], 'love');
    expect(reaction2.reactions[1], 'hate');

    var reaction2User = reaction2.user;
    expect(reaction2User.userId, 'userid');
    expect(reaction2User.avatarUrl, 'avatarurl');
    expect(reaction2User.displayName, 'testuser');
    expect(reaction2User.identities['fb'], 'token');
    expect(reaction2User.publicProperties['publickey'], 'publicvalue');
    expect(reaction2User.verified, true);

    var commenters = result.commenters;
    var commenter1 = commenters[0];
    expect(commenter1.userId, 'userid');
    expect(commenter1.avatarUrl, 'avatarurl');
    expect(commenter1.displayName, 'testuser');
    expect(commenter1.identities['fb'], 'token');
    expect(commenter1.publicProperties['publickey'], 'publicvalue');
    expect(commenter1.verified, true);

    var entity = result.source;
    expect(entity.avatarUrl, 'avatarurl');
    expect(entity.followersCount, 10);
    expect(entity.id, 'sourceid');
    expect(entity.isFollowedByMe, true);
    expect(entity.title, 'sourcetitle');
    expect(entity.type, CommunitiesEntityType.activity);

    var attachments = result.attachments;
    expect(attachments[0].imageUrl, 'imageurl');
    expect(attachments[1].imageUrl, 'imageurl2');

    var author = result.author;
    expect(author.userId, 'userid');
    expect(author.avatarUrl, 'avatarurl');
    expect(author.displayName, 'testuser');
    expect(author.identities['fb'], 'token');
    expect(author.publicProperties['publickey'], 'publicvalue');
    expect(author.verified, true);

    var poll = result.poll;
    expect(poll?.allowMultipleVotes, true);
    expect(poll?.endDate, 123);
    expect(poll?.totalVotes, 555);

    var voters = poll?.knownVoters;
    var voter1 = voters?[0];
    expect(voter1?.user.userId, 'userid');
    expect(voter1?.user.avatarUrl, 'avatarurl');
    expect(voter1?.user.displayName, 'testuser');
    expect(voter1?.user.identities['fb'], 'token');
    expect(voter1?.user.publicProperties['publickey'], 'publicvalue');
    expect(voter1?.user.verified, true);
    expect(voter1?.votes[0], 'vote');

    var voter2 = voters?[1];
    expect(voter2?.user.userId, 'userid');
    expect(voter2?.user.avatarUrl, 'avatarurl');
    expect(voter2?.user.displayName, 'testuser');
    expect(voter2?.user.identities['fb'], 'token');
    expect(voter2?.user.publicProperties['publickey'], 'publicvalue');
    expect(voter2?.user.verified, true);
    expect(voter2?.votes[0], 'vote1');
    expect(voter2?.votes[1], 'vote2');

    var pollOptions = poll?.options;
    var option1 = pollOptions?[0];
    expect(option1?.optionId, 'id1');
    expect(option1?.text, 'hello1');
    expect(option1?.attachment?.imageUrl, 'image1');
    expect(option1?.isVotedByMe, true);
    expect(option1?.voteCount, 100);

    var option2 = pollOptions?[1];
    expect(option2?.optionId, 'id2');
    expect(option2?.text, 'hello2');
    expect(option2?.attachment?.videoUrl, 'video2');
    expect(option2?.isVotedByMe, false);
    expect(option2?.voteCount, 200);
  });
}
