import 'dart:convert';

import 'package:flutter_test/flutter_test.dart';
import 'package:getsocial_flutter_sdk/getsocial_flutter_sdk.dart';

import '../test_utils.dart';

void main() {
  test('Decode', () {
    var obj = jsonDecode(TestUtils.readObjectToDecode('chat.json'));
    var result = Chat.fromJSON(obj);
    expect(result.id, 'chatid');
    expect(result.avatarUrl, 'avatar');
    expect(result.createdAt, 1234);
    expect(result.membersCount, 3);
    expect(result.title, 'chatwithuser');
    expect(result.updatedAt, 12345);

    var otherMember = result.otherMember;
    expect(otherMember.userId, 'userid');
    expect(otherMember.avatarUrl, 'avatarurl');
    expect(otherMember.displayName, 'testuser');
    expect(otherMember.identities['fb'], 'token');
    expect(otherMember.publicProperties['publickey'], 'publicvalue');
    expect(otherMember.verified, true);

    var lastMessage = result.lastMessage;
    expect(lastMessage?.id, 'messageid');
    expect(lastMessage?.text, 'hello');
    expect(lastMessage?.properties['messagekey'], 'messagevalue');
    expect(lastMessage?.sentAt, 12345);

    var attachments = lastMessage?.attachments;
    var attachment1 = attachments?[0];
    expect(attachment1?.imageUrl, 'imageurl');

    var attachment2 = attachments?[1];
    expect(attachment2?.imageUrl, 'imageurl2');

    var author = lastMessage?.author;
    expect(author?.userId, 'userid');
    expect(author?.avatarUrl, 'avatarurl');
    expect(author?.displayName, 'testuser');
    expect(author?.identities['fb'], 'token');
    expect(author?.publicProperties['publickey'], 'publicvalue');
    expect(author?.verified, true);
  });
}
