import 'dart:convert';

import 'package:flutter_test/flutter_test.dart';
import 'package:getsocial_flutter_sdk/getsocial_flutter_sdk.dart';

import '../test_utils.dart';

void main() {
  test('Decode', () {
    var obj = jsonDecode(TestUtils.readObjectToDecode('notification.json'));
    var result = GetSocialNotification.fromJSON(obj);
    expect(result.id, 'notificationid');
    expect(result.status, 'read');
    expect(result.text, 'text');
    expect(result.title, 'title');
    expect(result.type, 'comment');

    var action = result.notificationAction;
    expect(action?.type, 'hello');
    expect(action?.data['actionKey'], 'actionValue');

    var buttons = result.actionButtons;
    var button1 = buttons[0];
    expect(button1.title, 'button1');
    expect(button1.actionId, 'actionId1');

    var button2 = buttons[1];
    expect(button2.title, 'button2');
    expect(button2.actionId, 'actionId2');

    var customization = result.customization;
    expect(customization?.backgroundImageConfiguration, 'bgimage');
    expect(customization?.textColor, 'red');
    expect(customization?.titleColor, 'black');

    var attachment = result.mediaAttachment;
    expect(attachment?.videoUrl, 'videourl');

    var sender = result.sender;
    expect(sender?.userId, 'userid');
    expect(sender?.avatarUrl, 'avatarurl');
    expect(sender?.displayName, 'testuser');
    expect(sender?.identities['fb'], 'token');
    expect(sender?.publicProperties['publickey'], 'publicvalue');
    expect(sender?.verified, true);
  });
}
