import 'dart:convert';

import 'package:flutter_test/flutter_test.dart';
import 'package:getsocial_flutter_sdk/getsocial_flutter_sdk.dart';

import '../test_utils.dart';

void main() {
  test('FeedOf', () {
    var query = ActivitiesQuery.feedOf(UserId.create('test'));
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject(
            'activitiesquery', 'activitiesquery_feedof.json'));
  });

  test('FeedOfWithTag', () {
    var query = ActivitiesQuery.feedOf(UserId.create('test'));
    query = query.withTag('tag');
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject(
            'activitiesquery', 'activitiesquery_feedof_with_tag.json'));
  });

  test('InTopic', () {
    var query = ActivitiesQuery.inTopic('topicId');
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject(
            'activitiesquery', 'activitiesquery_intopic.json'));
  });

  test('InTopicByUser', () {
    var query = ActivitiesQuery.inTopic('topicId');
    query = query.byUser(UserId.create('test'));
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject(
            'activitiesquery', 'activitiesquery_intopic_byuser.json'));
  });

  test('InAllTopics', () {
    var query = ActivitiesQuery.inAllTopics();
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject(
            'activitiesquery', 'activitiesquery_inalltopics.json'));
  });

  test('InGroup', () {
    var query = ActivitiesQuery.inGroup('groupId');
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject(
            'activitiesquery', 'activitiesquery_ingroup.json'));
  });

  test('Timeline', () {
    var query = ActivitiesQuery.timeline();
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject(
            'activitiesquery', 'activitiesquery_timeline.json'));
  });

  test('Everywhere', () {
    var query = ActivitiesQuery.everywhere();
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject(
            'activitiesquery', 'activitiesquery_everywhere.json'));
  });

  test('Comments', () {
    var query = ActivitiesQuery.commentsToActivity('activityId');
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject(
            'activitiesquery', 'activitiesquery_comments.json'));
  });

  test('InTopicWithPollStatusAll', () {
    var query = ActivitiesQuery.inTopic('topicId');
    query.withPollStatus(PollStatus.all);
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject('activitiesquery',
            'activitiesquery_intopic_with_pollstatus_all.json'));
  });

  test('InTopicWithPollStatusVoted', () {
    var query = ActivitiesQuery.inTopic('topicId');
    query.withPollStatus(PollStatus.votedByMe);
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject('activitiesquery',
            'activitiesquery_intopic_with_pollstatus_voted.json'));
  });

  test('InTopicWithPollStatusNotVoted', () {
    var query = ActivitiesQuery.inTopic('topicId');
    query.withPollStatus(PollStatus.notVotedByMe);
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject('activitiesquery',
            'activitiesquery_intopic_with_pollstatus_notvoted.json'));
  });
}
