import 'dart:convert';

import 'package:flutter_test/flutter_test.dart';
import 'package:getsocial_flutter_sdk/getsocial_flutter_sdk.dart';

import '../test_utils.dart';

void main() {
  test('Text', () {
    var content = ActivityContent();
    content.text = 'hello';
    expect(
        jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject(
            'activitycontent', 'activitycontent_text.json'));
  });

  test('Properties', () {
    var content = ActivityContent();
    content.properties['propKey'] = 'propValue';
    expect(
        jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject(
            'activitycontent', 'activitycontent_properties.json'));
  });

  test('Attachment', () {
    var content = ActivityContent();
    content.attachments.add(MediaAttachment.withImageUrl('imageurl'));
    content.attachments.add(MediaAttachment.withVideoUrl('videourl'));
    expect(
        jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject(
            'activitycontent', 'activitycontent_attachments.json'));
  });

  test('ActivityButton', () {
    var content = ActivityContent();
    content.activityButton = ActivityButton(
        'title', GetSocialAction('show', {'actionkey': 'actionvalue'}));
    expect(
        jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject(
            'activitycontent', 'activitycontent_button.json'));
  });

  test('Poll', () {
    var content = ActivityContent();
    content.text = 'hello';

    var pollContent = PollContent();
    var option1 = PollOptionContent();
    option1.text = 'option1';
    option1.attachment = MediaAttachment.withImageUrl('image1');

    var option2 = PollOptionContent();
    option2.text = 'option2';
    option2.attachment = MediaAttachment.withImageUrl('image2');
    pollContent.options = [option1, option2];

    content.poll = pollContent;

    expect(
        jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject(
            'activitycontent', 'activitycontent_poll.json'));
  });

  test('Complete', () {
    var content = ActivityContent();
    content.text = 'hello';
    content.activityButton = ActivityButton(
        'title', GetSocialAction('show', {'actionkey': 'actionvalue'}));
    content.properties['propKey'] = 'propValue';
    content.attachments.add(MediaAttachment.withImageUrl('imageurl'));
    content.attachments.add(MediaAttachment.withVideoUrl('videourl'));

    var pollContent = PollContent();
    var option1 = PollOptionContent();
    option1.text = 'option1';
    option1.attachment = MediaAttachment.withImageUrl('image1');

    var option2 = PollOptionContent();
    option2.text = 'option2';
    option2.attachment = MediaAttachment.withImageUrl('image2');
    pollContent.options = [option1, option2];

    content.poll = pollContent;

    expect(
        jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject(
            'activitycontent', 'activitycontent_complete.json'));
  });
}
