import 'dart:convert';

import 'package:flutter_test/flutter_test.dart';
import 'package:getsocial_flutter_sdk/getsocial_flutter_sdk.dart';

import '../test_utils.dart';

void main() {
  test('FeedOf', () {
    var query = AnnouncementsQuery.forFeedOf(UserId.create('test'));
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject(
            'announcementsquery', 'announcementsquery_inuserfeed.json'));
  });

  test('InTopic', () {
    var query = AnnouncementsQuery.inTopic('topicid');
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject(
            'announcementsquery', 'announcementsquery_intopic.json'));
  });

  test('InGroup', () {
    var query = AnnouncementsQuery.inGroup('groupid');
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject(
            'announcementsquery', 'announcementsquery_ingroup.json'));
  });

  test('Timeline', () {
    var query = AnnouncementsQuery.timeline();
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject(
            'announcementsquery', 'announcementsquery_timeline.json'));
  });

  test('InTopicWithPollStatusAll', () {
    var query = AnnouncementsQuery.inTopic('topicid');
    query.withPollStatus(PollStatus.all);
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject('announcementsquery',
            'announcementsquery_intopic_with_pollstatus_all.json'));
  });

  test('InTopicWithPollStatusVoted', () {
    var query = AnnouncementsQuery.inTopic('topicid');
    query.withPollStatus(PollStatus.votedByMe);
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject('announcementsquery',
            'announcementsquery_intopic_with_pollstatus_voted.json'));
  });

  test('InTopicWithPollStatusNotVoted', () {
    var query = AnnouncementsQuery.inTopic('topicid');
    query.withPollStatus(PollStatus.notVotedByMe);
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject('announcementsquery',
            'announcementsquery_intopic_with_pollstatus_notvoted.json'));
  });
}
