import 'dart:convert';

import 'package:flutter_test/flutter_test.dart';
import 'package:getsocial_flutter_sdk/src/communitiesids.dart';
import 'package:getsocial_flutter_sdk/getsocial_flutter_sdk.dart';

import '../test_utils.dart';

void main() {
  test('Topic', () {
    var id = CommunitiesIds.topic('topicid');
    expect(
        jsonEncode(id.toJSON()),
        TestUtils.readEncodedObject(
            'communitiesid', 'communitiesid_topic.json'));
  });

  test('Topics', () {
    var id = CommunitiesIds.topics(['topicid', 'topicid2']);
    expect(
        jsonEncode(id.toJSON()),
        TestUtils.readEncodedObject(
            'communitiesid', 'communitiesid_topics.json'));
  });

  test('Group', () {
    var id = CommunitiesIds.group('groupid');
    expect(
        jsonEncode(id.toJSON()),
        TestUtils.readEncodedObject(
            'communitiesid', 'communitiesid_group.json'));
  });

  test('Groups', () {
    var id = CommunitiesIds.groups(['groupid', 'groupid2']);
    expect(
        jsonEncode(id.toJSON()),
        TestUtils.readEncodedObject(
            'communitiesid', 'communitiesid_groups.json'));
  });

  test('User', () {
    var id = CommunitiesIds.user(UserId.create('bob'));
    expect(
        jsonEncode(id.toJSON()),
        TestUtils.readEncodedObject(
            'communitiesid', 'communitiesid_user.json'));
  });

  test('Users', () {
    var id = CommunitiesIds.users(UserIdList.create(['bob', 'jay']));
    expect(
        jsonEncode(id.toJSON()),
        TestUtils.readEncodedObject(
            'communitiesid', 'communitiesid_users.json'));
  });

  test('Activity', () {
    var id = CommunitiesIds.activity('activityid');
    expect(
        jsonEncode(id.toJSON()),
        TestUtils.readEncodedObject(
            'communitiesid', 'communitiesid_activity.json'));
  });

  test('Timeline', () {
    var id = CommunitiesIds.timeline();
    expect(
        jsonEncode(id.toJSON()),
        TestUtils.readEncodedObject(
            'communitiesid', 'communitiesid_timeline.json'));
  });

  test('Everywhere', () {
    var id = CommunitiesIds.everywhere();
    expect(
        jsonEncode(id.toJSON()),
        TestUtils.readEncodedObject(
            'communitiesid', 'communitiesid_everywhere.json'));
  });
}
