import 'dart:convert';

import 'package:flutter_test/flutter_test.dart';
import 'package:getsocial_flutter_sdk/getsocial_flutter_sdk.dart';

import '../test_utils.dart';

void main() {
  test('Title', () {
    var content = GroupContent();
    content.id = 'groupid';
    content.title = 'grouptitle';
    expect(jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject('groupcontent', 'groupcontent_title.json'));
  });

  test('Description', () {
    var content = GroupContent();
    content.id = 'groupid';
    content.description = 'groupdescription';
    expect(
        jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject(
            'groupcontent', 'groupcontent_description.json'));
  });

  test('Properties', () {
    var content = GroupContent();
    content.id = 'groupid';
    content.properties['propkey'] = 'propvalue';
    expect(
        jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject(
            'groupcontent', 'groupcontent_properties.json'));
  });

  test('Avatar', () {
    var content = GroupContent();
    content.id = 'groupid';
    content.avatar = MediaAttachment.withImageUrl('image1');
    expect(
        jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject(
            'groupcontent', 'groupcontent_attachment.json'));
  });

  test('Permission', () {
    var content = GroupContent();
    content.id = 'groupid';
    content.permissions[CommunitiesAction.comment] = Role.owner;
    expect(
        jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject(
            'groupcontent', 'groupcontent_permission.json'));
  });

  test('Complete', () {
    var content = GroupContent();
    content.id = 'groupid';
    content.title = 'grouptitle';
    content.description = 'groupdescription';
    content.avatar = MediaAttachment.withImageUrl('image1');
    content.properties['propkey'] = 'propvalue';
    content.permissions[CommunitiesAction.comment] = Role.owner;
    expect(
        jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject(
            'groupcontent', 'groupcontent_complete.json'));
  });
}
