import 'dart:convert';

import 'package:flutter_test/flutter_test.dart';
import 'package:getsocial_flutter_sdk/getsocial_flutter_sdk.dart';

import '../test_utils.dart';

void main() {
  test('WithText', () {
    var content = NotificationContent();
    content.text = 'hello';
    expect(
        jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject(
            'notificationcontent', 'notificationcontent_with_text.json'));
  });

  test('WithTemplate', () {
    var content = NotificationContent();
    content.templateName = 'template';
    expect(
        jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject(
            'notificationcontent', 'notificationcontent_with_template.json'));
  });

  test('WithTextComplete', () {
    var content = NotificationContent();
    content.text = 'hello';
    content.actionButtons.add(NotificationButton('title', 'actionid'));
    content.title = 'title';
    content.badge = NotificationBadge.increaseBy(5);
    content.action = GetSocialAction('open', {'key': 'value'});
    content.mediaAttachment = MediaAttachment.withImageUrl('imageurl');
    var customization = NotificationCustomization();
    customization.backgroundImageConfiguration = 'bg';
    customization.titleColor = 'titlecolor';
    customization.textColor = 'textcolor';

    content.customization = customization;
    expect(
        jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject('notificationcontent',
            'notificationcontent_with_text_complete.json'));
  });

  test('WithTemplateComplete', () {
    var content = NotificationContent();
    content.templateName = 'template';
    content.templatePlaceholders['placeholderkey'] = 'placeholdervalue';
    expect(
        jsonEncode(content.toJSON()),
        TestUtils.readEncodedObject('notificationcontent',
            'notificationcontent_with_template_complete.json'));
  });
}
