import 'dart:convert';

import 'package:flutter_test/flutter_test.dart';
import 'package:getsocial_flutter_sdk/getsocial_flutter_sdk.dart';

import '../test_utils.dart';

void main() {
  var groupId = 'groupId';
  var userIdList = UserIdList.create(['test']);

  test('Test', () {
    var query = UpdateGroupMembersQuery.create(groupId, userIdList);
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject(
            'updategroupmembersquery', 'updategroupmembersquery.json'));
  });

  test('WithMemberRole', () {
    var query = UpdateGroupMembersQuery.create(groupId, userIdList);
    query.role = Role.admin;
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject('updategroupmembersquery',
            'updategroupmembersquery_with_memberrole.json'));
  });

  test('WithMemberStatus', () {
    var query = UpdateGroupMembersQuery.create(groupId, userIdList);
    query.status = MemberStatus.member;
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject('updategroupmembersquery',
            'updategroupmembersquery_with_memberstatus.json'));
  });

  test('WithMemberRoleAndStatus', () {
    var query = UpdateGroupMembersQuery.create(groupId, userIdList);
    query.role = Role.admin;
    query.status = MemberStatus.member;
    expect(
        jsonEncode(query.toJSON()),
        TestUtils.readEncodedObject('updategroupmembersquery',
            'updategroupmembersquery_with_memberstatusandrole.json'));
  });
}
